@@ -1,14 +1,13 @@
 import argparse
 import asyncio
-from typing import Iterable
+from typing import Iterable, AsyncIterable
 import logging
 
 from dblp_crawler import Publication
 from dblp_crawler.keyword import Keywords
 from dblp_crawler.keyword.arg import add_argument as add_argument_kw, parse_args as parse_args_kw
 from dblp_crawler.arg import add_argument_pid, add_argument_journal, parse_args_pid_journal
-from dblp_crawler.summarizer.networkx import NetworkxGraph
-from dblp_crawler.summarizer.neo4j import Neo4jGraph
+from dblp_crawler.summarizer import NetworkxGraph, Neo4jGraph
 
 logging.basicConfig(level=logging.INFO)
 logger = logging.getLogger('dblp_crawler')
@@ -16,6 +15,7 @@ logger = logging.getLogger('dblp_crawler')
 parser = argparse.ArgumentParser()
 
 parser.add_argument("-y", "--year", type=int, help="Only crawl the paper after the specified year.", default=2000)
+parser.add_argument("-l", "--limit", type=int, help="Limitation of BFS depth.", default=-1)
 add_argument_kw(parser)
 add_argument_pid(parser)
 add_argument_journal(parser)
@@ -24,28 +24,31 @@ add_argument_journal(parser)
 def func_parser(parser):
     args = parser.parse_args()
     year = args.year
+    limit = args.limit
     keywords = parse_args_kw(parser)
     pid_list, journal_list = parse_args_pid_journal(parser)
     logger.info(f"Specified keyword rules: {keywords.rules}")
-    logger.info(f"Specified pid_list for init: {pid_list}")
-    logger.info(f"Specified journal_list for init: {journal_list}")
-    return year, keywords, pid_list, journal_list
+    logger.info(f"Specified persons for init: {pid_list}")
+    logger.info(f"Specified journals or conferences for init: {journal_list}")
+    logger.info(f"Specified BFS depth limitation: {limit}")
+    return year, keywords, pid_list, journal_list, limit
 
 
-def filter_publications_at_crawler(publications, keywords: Keywords):
-    for publication in publications:
-        if keywords.match_words(publication.title()):
-            yield publication
-
-
-def filter_publications_at_output(publications, year: int, keywords: Keywords):
+def filter_publications_at_crawler(publications, year: int, keywords: Keywords):
     for publication in publications:
         if publication.year() >= year and keywords.match(publication.title()):
             yield publication
 
 
 async def bfs_to_end(graph, limit: int = 0):
-    while min(*(await graph.bfs_once())) > 0 and (limit != 0):
+    while limit != 0:
+        remain_none, total_author_count, all_fail = await graph.bfs_once()
+        if all_fail:
+            logger.info("Downloading all failed, exit")
+            return
+        if (remain_none + total_author_count) <= 0:
+            logger.info("No more need downloaded, exit")
+            return
         logger.info("Still running......")
         limit -= 1
 
@@ -62,10 +65,11 @@ class NetworkxGraphDefault(NetworkxGraph):
         self.keywords = keywords
 
     def filter_publications_at_crawler(self, publications: Iterable[Publication]) -> Iterable[Publication]:
-        yield from filter_publications_at_crawler(publications, self.keywords)
+        yield from filter_publications_at_crawler(publications, self.year, self.keywords)
 
-    def filter_publications_at_output(self, publications: Iterable[Publication]) -> Iterable[Publication]:
-        yield from filter_publications_at_output(publications, self.year, self.keywords)
+    async def filter_publications_at_output(self, publications: AsyncIterable[Publication]) -> AsyncIterable[Publication]:
+        async for publication in publications:
+            yield publication
 
 
 parser_nx = subparsers.add_parser('networkx', help='Write results to a json file.')
@@ -73,12 +77,12 @@ parser_nx.add_argument("--dest", type=str, required=True, help=f'Path to write r
 
 
 def func_parser_nx(parser):
-    year, keywords, pid_list, journal_list = func_parser(parser)
+    year, keywords, pid_list, journal_list, limit = func_parser(parser)
     args = parser.parse_args()
     dest = args.dest
     logger.info(f"Specified dest: {dest}")
     g = NetworkxGraphDefault(year=year, keywords=keywords, pid_list=pid_list, journal_list=journal_list)
-    asyncio.get_event_loop().run_until_complete(bfs_to_end(g))
+    asyncio.get_event_loop().run_until_complete(bfs_to_end(g, limit))
     summary = g.dict_summary()
 
     import json
@@ -100,31 +104,35 @@ class Neo4jGraphDefault(Neo4jGraph):
         self.keywords = keywords
 
     def filter_publications_at_crawler(self, publications: Iterable[Publication]) -> Iterable[Publication]:
-        yield from filter_publications_at_crawler(publications, self.keywords)
+        yield from filter_publications_at_crawler(publications, self.year, self.keywords)
 
-    def filter_publications_at_output(self, publications: Iterable[Publication]) -> Iterable[Publication]:
-        yield from filter_publications_at_output(publications, self.year, self.keywords)
+    async def filter_publications_at_output(self, publications: AsyncIterable[Publication]) -> AsyncIterable[Publication]:
+        async for publication in publications:
+            yield publication
 
 
 parser_n4j = subparsers.add_parser('neo4j', help='Write result to neo4j database')
-parser_n4j.add_argument("--auth", type=str, default=None, help=f'Auth to neo4j database.')
+parser_n4j.add_argument("--username", type=str, default=None, help=f'Auth username to neo4j database.')
+parser_n4j.add_argument("--password", type=str, default=None, help=f'Auth password to neo4j database.')
 parser_n4j.add_argument("--uri", type=str, required=True, help=f'URI to neo4j database.')
+parser_n4j.add_argument("--select", action='store_true',
+                        help=f'Mark keyword-matched publications in database (set selected=true).')
 
 
 def func_parser_n4j(parser):
     from neo4j import GraphDatabase
-    year, keywords, pid_list, journal_list = func_parser(parser)
+    year, keywords, pid_list, journal_list, limit = func_parser(parser)
     args = parser.parse_args()
-    logger.info(f"Specified uri and auth: {args.uri} {args.auth}")
+    logger.info(f"Specified uri and auth: {args.uri} {args.username} {'******' if args.password else 'none'}")
 
-    with GraphDatabase.driver(args.uri, auth=args.auth) as driver:
+    with GraphDatabase.driver(args.uri, auth=(args.username, args.password)) as driver:
         with driver.session() as session:
             g = Neo4jGraphDefault(
-                year=year, keywords=keywords, session=session,
+                year=year, keywords=keywords,
+                session=session, select=args.select,
                 pid_list=pid_list, journal_list=journal_list)
-            asyncio.get_event_loop().run_until_complete(bfs_to_end(g))
             logger.info(f"Summarizing to: {args.uri}")
-            g.summarize()
+            asyncio.get_event_loop().run_until_complete(bfs_to_end(g, limit))
 
 
 parser_n4j.set_defaults(func=func_parser_n4j)
