@@ -1,10 +1,11 @@
 import re
+from typing import Set
 
 
 class Keywords:
     def __init__(self) -> None:
-        self.rules: set[tuple[str, ...]] = set()
-        self.words: set[str] = set()
+        self.rules: Set[tuple[str, ...]] = set()
+        self.words: Set[str] = set()
 
     def add_rule(self, *rule: str) -> None:
         """与关系的单词列"""
@@ -12,7 +13,7 @@ class Keywords:
         self.rules.add(rule)
         self.words = self.words.union(rule)
 
-    def add_rule_list(self, *rule_list: set[str]) -> None:
+    def add_rule_list(self, *rule_list: Set[str]) -> None:
         """多个与关系的单词列"""
         for rule in rule_list:
             self.add_rule(*rule)
@@ -21,6 +22,8 @@ class Keywords:
         self.add_rule_list(*list(set(word, ) for word in words))
 
     def match(self, sentence: str) -> bool:
+        if len(self.rules) <= 0 and len(self.words) <= 0:
+            return True  # 没有规则就全过
         sentence = sentence.lower()
         words = set(re.findall(r"\w+", sentence))
         for rule in self.rules:  # 只要有一个rule能匹配上就返回True
@@ -29,6 +32,8 @@ class Keywords:
         return False
 
     def match_words(self, sentence: str) -> bool:
+        if len(self.rules) <= 0 and len(self.words) <= 0:
+            return True  # 没有规则就全过
         sentence = sentence.lower()
         # 所有rule全切成一个个单词，只要包含其中一个单词就返回True
         return len(set(re.findall(r"\w+", sentence)).intersection(self.words)) > 0
