@@ -4,10 +4,15 @@ from .downloader import *
 from typing import Optional, Iterator
 import re
 import logging
+from urllib.parse import urlparse
 
 logger = logging.getLogger("parser")
 
 
+def title_hash(title):
+    return re.sub(r"[^0-9a-z\u4E00-\u9FFF\uFB00-\uFEFF]", "", title.lower()) or title.lower()
+
+
 class Person:
     def __init__(self, data: ElementTree.Element) -> None:
         assert data.tag == "person", "Should be xml of a person in dblpperson!"
@@ -37,6 +42,9 @@ class Author:
     def pid(self) -> str:
         return self.data.attrib['pid']
 
+    def orcid(self) -> str:
+        return self.data.attrib['orcid'] if 'orcid' in self.data.attrib else None
+
     async def dblpperson(self):
         data = await download_person(self.pid())
         if data is None:
@@ -44,6 +52,13 @@ class Author:
         return DBLPPerson(data)
 
 
+def url2doi(url):
+    u = urlparse(url)
+    if u.netloc != "doi.org":
+        return None
+    return re.sub(r"^/+", "", u.path)
+
+
 class Publication:
     def __init__(self, data: ElementTree.Element) -> None:
         assert data.tag == "r", "Should be xml of a <r> tag in dblpperson!"
@@ -57,11 +72,13 @@ class Publication:
             if child.tag == "author":
                 yield Author(child)
 
-    def title(self) -> Optional[str]:
+    def title(self) -> str:
         for child in self.data:
             if child.tag == "title":
                 return " ".join(t for t in child.itertext())
-        return None
+
+    def title_hash(self) -> str:
+        return title_hash(self.title())
 
     def journal(self) -> Optional[str]:
         tag = {
@@ -88,6 +105,9 @@ class Publication:
                 return int(child.text) if child.text is not None else None
         return None
 
+    def mdate(self) -> Optional[str]:
+        return self.data.attrib["mdate"]
+
     def ee(self) -> Iterator[str]:
         for child in self.data:
             if child.tag == "ee":
@@ -96,8 +116,9 @@ class Publication:
 
     def doi(self) -> Optional[str]:
         for e in self.ee():
-            if re.search(r'doi\.org', e) is not None:
-                return e
+            doi = url2doi(e)
+            if doi is not None:
+                return doi
         return None
 
     def ccf(self) -> str:
@@ -109,15 +130,22 @@ class Publication:
 
     def __dict__(self) -> dict:
         return dict(
-            key=self.key(),
+            dblp_key=self.key(),
             title=self.title(),
+            title_hash=self.title_hash(),
             journal=self.journal(),
             journal_key=self.journal_key(),
             year=self.year(),
+            mdate=self.mdate(),
             doi=self.doi(),
             ccf=self.ccf(),
-            authors=", ".join([author.name() for author in self.authors()])[0:-2],
-            authors_pid=[author.pid() for author in self.authors()],
+            authors={
+                author.pid(): {
+                    "dblp_pid": author.pid(),
+                    "name": author.name(),
+                    "orcid": author.orcid(),
+                } for author in self.authors()
+            },
         )
 
 
@@ -151,7 +179,7 @@ class DBLPPerson:
     def __dict__(self) -> dict:
         person = self.person()
         return dict(
-            pid=self.pid(),
+            dblp_pid=self.pid(),
             name=self.name(),
             affiliations=list(person.affiliations()),
             publications=[pub.key() for pub in self.publications()]
@@ -161,10 +189,8 @@ class DBLPPerson:
 if __name__ == "__main__":
     logging.basicConfig(level=logging.DEBUG)
 
-
     async def main() -> None:
         print(DBLPPerson(await download_person('74/1552-1')))
 
-
     loop = asyncio.get_event_loop()
     loop.run_until_complete(main())
